/*
 * libslb.h - internal header file.
 * Used only when compiling the shared library code,
 * to redirect standard library functions to the
 * library that was linked to the application
 *
 * Copyright (C) 2019 Thorsten Otto
 */

#ifndef __FREETYPESLB_H__
#define __FREETYPESLB_H__ 1

#include <stdio.h>
#include <fcntl.h>
#include <errno.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include <setjmp.h>
#include <unistd.h>

#undef memset
#undef memcpy
#undef memcmp
#undef memmove
#undef memchr

#undef strlen
#undef strcpy
#undef strncpy
#undef strcat
#undef strcmp
#undef strncmp
#undef strstr
#undef strrchr
#undef strtol

#undef malloc
#undef free
#undef realloc

#undef fopen
#undef fclose
#undef fread
#undef fwrite
#undef sprintf
#undef ftell
#undef fseek

#undef sigsetjmp
#undef setjmp
#undef longjmp

#undef qsort
#undef getenv

#include "libstrct.h"

#define memset(d, c, l) freetype_get_slb_funcs()->p_memset(d, c, l)
#define memcpy(d, s, l) freetype_get_slb_funcs()->p_memcpy(d, s, l)
#define memmove(d, s, l) freetype_get_slb_funcs()->p_memcpy(d, s, l)
#define memcmp(d, s, l) freetype_get_slb_funcs()->p_memcmp(d, s, l)
#define memchr(s, c, n) freetype_get_slb_funcs()->p_memchr(s, c, n)

#define strlen freetype_get_slb_funcs()->p_strlen
#define strcpy freetype_get_slb_funcs()->p_strcpy
#define strncpy freetype_get_slb_funcs()->p_strncpy
#define strcat freetype_get_slb_funcs()->p_strcat
#define strcmp freetype_get_slb_funcs()->p_strcmp
#define strncmp freetype_get_slb_funcs()->p_strncmp
#define strstr freetype_get_slb_funcs()->p_strstr
#define strrchr freetype_get_slb_funcs()->p_strrchr
#define strtol freetype_get_slb_funcs()->p_strtol

#define malloc(s) freetype_get_slb_funcs()->p_malloc(s)
#define free(p) freetype_get_slb_funcs()->p_free(p)
#define realloc(ptr, s) freetype_get_slb_funcs()->p_realloc(ptr, s)

#define fopen freetype_get_slb_funcs()->p_fopen
#define fclose freetype_get_slb_funcs()->p_fclose
#define fread freetype_get_slb_funcs()->p_fread
#define fwrite freetype_get_slb_funcs()->p_fwrite
#define sprintf freetype_get_slb_funcs()->p_sprintf
#define ftell freetype_get_slb_funcs()->p_ftell
#define fseek freetype_get_slb_funcs()->p_fseek

#define sigsetjmp freetype_get_slb_funcs()->p_sigsetjmp
#define setjmp(j) freetype_get_slb_funcs()->p_sigsetjmp(j, 1)
#define longjmp freetype_get_slb_funcs()->p_longjmp

#define qsort freetype_get_slb_funcs()->p_qsort
#define getenv freetype_get_slb_funcs()->p_getenv

/*
 * used to load libraries only if needed
 */
long slb_freetype_zlib_open(void);
long slb_freetype_bzip2_open(void);
long slb_freetype_png_open(void);
long slb_freetype_harfbuzz_open(void);

#endif /* __FREETYPESLB_H__ */
