/****************************************************************************
 *
 * fterrors.c
 *
 *   FreeType API for error code handling.
 *
 * Copyright (C) 2018-2019 by
 * Armin Hasitzka, David Turner, Robert Wilhelm, and Werner Lemberg.
 *
 * This file is part of the FreeType project, and may only be used,
 * modified, and distributed under the terms of the FreeType project
 * license, LICENSE.TXT.  By continuing to use, modify, or distribute
 * this file you indicate that you have read the license and
 * understand and accept it fully.
 *
 */


#include <ft2bld.h>
#include <ft2build.h>
#include <freetype/internal/ftdebug.h>
#include <freetype/fterrors.h>

ANONYMOUS_STRUCT_DUMMY(FT_Slot_InternalRec_)
ANONYMOUS_STRUCT_DUMMY(FT_SubGlyphRec_)
ANONYMOUS_STRUCT_DUMMY(FT_Size_InternalRec_)
ANONYMOUS_STRUCT_DUMMY(FT_Face_InternalRec_)
ANONYMOUS_STRUCT_DUMMY(FT_RendererRec_)
ANONYMOUS_STRUCT_DUMMY(FT_DriverRec_)
ANONYMOUS_STRUCT_DUMMY(FT_ModuleRec_)
ANONYMOUS_STRUCT_DUMMY(FT_LibraryRec_)
ANONYMOUS_STRUCT_DUMMY(FT_RasterRec_)

#if defined( FT_CONFIG_OPTION_ERROR_STRINGS ) || defined( FT_DEBUG_LEVEL_ERROR )
#undef FTERRORS_H_
#undef __FTERRORS_H__
#define FT_ERRORDEF( e, v, s )  { e, s },
#define FT_ERROR_START_LIST
#define FT_ERROR_END_LIST

static struct
{
	FT_Error err_code;
	const char *err_msg;
} const ft_errors[] = {
#include <freetype/fterrors.h>
};

#endif


  /* documentation is in fterrors.h */

  FT_EXPORT_DEF( const char* )
  FT_Error_String( FT_Error  error_code )
  {
#if defined( FT_CONFIG_OPTION_ERROR_STRINGS ) || defined( FT_DEBUG_LEVEL_ERROR )
	size_t i;

	for (i = 0; i < (sizeof(ft_errors) / sizeof(ft_errors[0])); i++)
		if (ft_errors[i].err_code == error_code)
			return ft_errors[i].err_msg;
#else
    FT_UNUSED(error_code);
#endif /* defined( FT_CONFIG_OPTION_ERROR_STRINGS ) || ... */

    return NULL;
  }
